@@ -2,7 +2,7 @@ package DBIx::Skinny;
 use strict;
 use warnings;
 
-our $VERSION = '0.0708';
+our $VERSION = '0.0709';
 
 use DBI;
 use DBIx::Skinny::Iterator;
@@ -11,7 +11,7 @@ use DBIx::Skinny::Row;
 use DBIx::Skinny::Profiler;
 use DBIx::Skinny::Profiler::Trace;
 use DBIx::Skinny::Transaction;
-use Digest::SHA1;
+use Digest::SHA1 ();
 use Carp ();
 use Storable;
 
@@ -29,7 +29,7 @@ sub import {
         dsn             => $args->{dsn},
         username        => $args->{username},
         password        => $args->{password},
-        coddnnect_options => $args->{connect_options},
+        connect_options => $args->{connect_options},
         on_connect_do   => $args->{on_connect_do},
         dbh             => $args->{dbh}||undef,
         dbd             => $dbd_type ? DBIx::Skinny::DBD->new($dbd_type) : undef,
